==> chromium_81.0.4044.62.orig.tar.xz: chromium-81.0.4044.62/chrome/browser/permissions/contextual_notification_permission_ui_selector.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_
#define CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_

#include "base/callback.h"
#include "base/optional.h"
#include "chrome/browser/permissions/crowd_deny_safe_browsing_request.h"
#include "chrome/browser/permissions/notification_permission_ui_selector.h"

class Profile;

namespace permissions {
class PermissionRequest;
}

namespace url {
class Origin;
}

// Determines if the quiet prompt UI should be used to display a notification
// permission request on a given site. This is the case when:
//  1) the quiet UI is enabled in prefs for all sites, either directly by the
//     user in settings, or by the AdaptiveQuietNotificationPermissionUiEnabler.
//  2) the quiet UI is triggered by crowd deny, either through:
//     a) CrowdDenyPreloadData, that is, the component updater, or
//     b) CrowdDenySafeBrowsingRequest, that is, on-demand Safe Browsing pings.
// If both (1) and (2) are fulfilled, the crowd-deny UI is shown.
//
// Each instance of this class is long-lived and can support multiple requests,
// but only one at a time.
class ContextualNotificationPermissionUiSelector
    : public NotificationPermissionUiSelector {
 public:
  // Constructs an instance in the context of the given |profile|.
  explicit ContextualNotificationPermissionUiSelector(Profile* profile);
  ~ContextualNotificationPermissionUiSelector() override;

  // NotificationPermissionUiSelector:
  void SelectUiToUse(permissions::PermissionRequest* request,
                     DecisionMadeCallback callback) override;

  void Cancel() override;

 private:
  ContextualNotificationPermissionUiSelector(
      const ContextualNotificationPermissionUiSelector&) = delete;
  ContextualNotificationPermissionUiSelector& operator=(
      const ContextualNotificationPermissionUiSelector&) = delete;

  void EvaluateCrowdDenyTrigger(url::Origin origin);
  void OnSafeBrowsingVerdictReceived(
      CrowdDenySafeBrowsingRequest::Verdict verdict);
  void OnCrowdDenyTriggerEvaluated(UiToUse ui_to_use);

  void Notify(UiToUse ui_to_use, base::Optional<QuietUiReason> quiet_ui_reason);

  Profile* profile_;

  base::Optional<CrowdDenySafeBrowsingRequest> safe_browsing_request_;
  DecisionMadeCallback callback_;
};

#endif  // CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_

==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/permissions/contextual_notification_permission_ui_selector.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_
#define CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_

#include "base/callback.h"
#include "base/optional.h"
#include "chrome/browser/permissions/crowd_deny_safe_browsing_request.h"
#include "components/permissions/notification_permission_ui_selector.h"

namespace permissions {
class PermissionRequest;
}

namespace url {
class Origin;
}

// Determines if crowd deny or abusive blocklists prescribe that the quiet UI
// should be used to display a notification permission request on a given site.
// This is the case when the  both of the below sources classify the origin as
// spammy or abusive:
//   a) CrowdDenyPreloadData, that is, the component updater, and
//   b) CrowdDenySafeBrowsingRequest, that is, on-demand Safe Browsing pings.
//
// Each instance of this class is long-lived and can support multiple requests,
// but only one at a time.
class ContextualNotificationPermissionUiSelector
    : public permissions::NotificationPermissionUiSelector {
 public:
  ContextualNotificationPermissionUiSelector();
  ~ContextualNotificationPermissionUiSelector() override;

  // NotificationPermissionUiSelector:
  void SelectUiToUse(permissions::PermissionRequest* request,
                     DecisionMadeCallback callback) override;

  void Cancel() override;

 private:
  ContextualNotificationPermissionUiSelector(
      const ContextualNotificationPermissionUiSelector&) = delete;
  ContextualNotificationPermissionUiSelector& operator=(
      const ContextualNotificationPermissionUiSelector&) = delete;

  void EvaluatePerSiteTriggers(const url::Origin& origin);
  void OnSafeBrowsingVerdictReceived(
      Decision candidate_decision,
      CrowdDenySafeBrowsingRequest::Verdict verdict);
  void Notify(const Decision& decision);

  base::Optional<CrowdDenySafeBrowsingRequest> safe_browsing_request_;
  DecisionMadeCallback callback_;
};

#endif  // CHROME_BROWSER_PERMISSIONS_CONTEXTUAL_NOTIFICATION_PERMISSION_UI_SELECTOR_H_
